#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['educationwarehouse']

package_data = \
{'': ['*']}

extras_require = \
{'dev': ['python-semantic-release',
         'flit',
         'devpi-client',
         'black[d]',
         'invoke']}

entry_points = \
{'console_scripts': ['edwh = console_entry_points:edwh']}

setup(name='educationwarehouse',
      version='0.0.0',
      description="EducationWarehouse uses `EDWH` as it's internal abbreviation.",
      author='Education Warehouse',
      author_email='remco.b@educationwarehouse.nl',
      url='https://www.educationwarehouse.nl',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      entry_points=entry_points,
     )
